@@ -48,6 +48,10 @@
 
 #define QT_FEATURE_syslog -1
 
+#define QT_FEATURE_backtrace 1
+
+#define QT_FEATURE_cpp_winrt -1
+
 #define QT_FEATURE_sha3_fast 1
 
 #define QT_FEATURE_hijricalendar 1
