@@ -98,6 +98,7 @@ public:
         ByteOrderSwapped = 0xfffe,
         ParagraphSeparator = 0x2029,
         LineSeparator = 0x2028,
+        VisualTabCharacter = 0x2192,
         LastValidCodePoint = 0x10ffff
     };
 
@@ -111,8 +112,8 @@ public:
     constexpr Q_IMPLICIT QChar(ushort rc) noexcept : ucs(rc) {}
     constexpr QCHAR_MAYBE_IMPLICIT QChar(uchar c, uchar r) noexcept : ucs(char16_t((r << 8) | c)) {}
     constexpr Q_IMPLICIT QChar(short rc) noexcept : ucs(char16_t(rc)) {}
-    constexpr QCHAR_MAYBE_IMPLICIT QChar(uint rc) noexcept : ucs(char16_t(rc & 0xffff)) {}
-    constexpr QCHAR_MAYBE_IMPLICIT QChar(int rc) noexcept : ucs(char16_t(rc & 0xffff)) {}
+    constexpr QCHAR_MAYBE_IMPLICIT QChar(uint rc) noexcept : ucs((Q_ASSERT(rc <= 0xffff), char16_t(rc))) {}
+    constexpr QCHAR_MAYBE_IMPLICIT QChar(int rc) noexcept : QChar(uint(rc)) {}
     constexpr Q_IMPLICIT QChar(SpecialCharacter s) noexcept : ucs(char16_t(s)) {}
     constexpr Q_IMPLICIT QChar(QLatin1Char ch) noexcept : ucs(ch.unicode()) {}
     constexpr Q_IMPLICIT QChar(char16_t ch) noexcept : ucs(ch) {}
@@ -362,6 +363,13 @@ public:
         Script_KhitanSmallScript,
         Script_Yezidi,
 
+        // Unicode 14.0 additions
+        Script_CyproMinoan,
+        Script_OldUyghur,
+        Script_Tangsa,
+        Script_Toto,
+        Script_Vithkuqi,
+
         ScriptCount
     };
 
@@ -452,7 +460,8 @@ public:
         Unicode_11_0,
         Unicode_12_0,
         Unicode_12_1,
-        Unicode_13_0
+        Unicode_13_0,
+        Unicode_14_0
     };
 
     inline Category category() const noexcept { return QChar::category(ucs); }
@@ -638,7 +647,7 @@ private:
     char16_t ucs;
 };
 
-Q_DECLARE_TYPEINFO(QChar, Q_RELOCATABLE_TYPE);
+Q_DECLARE_TYPEINFO(QChar, Q_PRIMITIVE_TYPE);
 
 #ifndef QT_NO_DATASTREAM
 Q_CORE_EXPORT QDataStream &operator<<(QDataStream &, QChar);
