@@ -28,8 +28,12 @@
 
 #define QT_FEATURE_cxx1z 1
 
+#define QT_FEATURE_cxx20 -1
+
 #define QT_FEATURE_cxx2a -1
 
+#define QT_FEATURE_cxx2b -1
+
 #define QT_FEATURE_c99 1
 
 #define QT_FEATURE_c11 1
@@ -45,12 +49,12 @@
 #define QT_FEATURE_dbus 1
 
 
-#define QT_VERSION_STR "6.0.4"
+#define QT_VERSION_STR "6.3.1"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 0
+#define QT_VERSION_MINOR 3
 
-#define QT_VERSION_PATCH 4
+#define QT_VERSION_PATCH 1
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
