@@ -1,3 +1,5 @@
+#define QT_FEATURE_ifr_index 1
+
 #define QT_FEATURE_libproxy -1
 
 #define QT_FEATURE_linux_netlink -1
@@ -8,5 +10,5 @@
 
 #define QT_FEATURE_system_proxies 1
 
-#define QT_FEATURE_netlistmgr -1
+#define QT_FEATURE_networklistmanager -1
 
